@@ -1,13 +1,21 @@
 import json
 from django import template
-from django.templatetags.static import static
+from django.contrib.staticfiles.templatetags.staticfiles import static
 from django.urls import reverse
 from django.utils.safestring import mark_safe
 from ..utils import random_string
-
+from ..html_include import html_include
 register = template.Library()
 
 
+@register.simple_tag
+def lib_include(*args, **kwargs):
+    include_str = ''
+    for a in args:
+        include_str += html_include(a, cdn=kwargs.get('cdn'), module=kwargs.get('module'))
+    return mark_safe(include_str)
+
+
 @register.simple_tag
 def init_ajax():
     return mark_safe(f'<script src="{static("ajax_helpers/ajax_helpers.js")}"></script>')
@@ -24,7 +32,7 @@ def button_javascript(button_name, url_name=None, url_args=None, **kwargs):
     json_data = {'data': dict(button=button_name, **kwargs)}
     if url_name:
         json_data['url'] = reverse(url_name, args=url_args)
-    return f'ajax_helpers.post_json({json.dumps(json_data)})'
+    return mark_safe(f'ajax_helpers.post_json({json.dumps(json_data)})')
 
 
 @register.simple_tag
